@@ -176,6 +176,13 @@ pub struct AcceleratorKeyPressedEventHandler(
     Option<ICoreWebView2AcceleratorKeyPressedEventArgs>,
 );
 
+#[event_callback]
+pub struct ProcessInfosChangedEventHandler(
+    ICoreWebView2ProcessInfosChangedEventHandler,
+    Option<ICoreWebView2Environment>,
+    Option<IUnknown>,
+);
+
 #[event_callback]
 pub struct RasterizationScaleChangedEventHandler(
     ICoreWebView2RasterizationScaleChangedEventHandler,
@@ -371,6 +378,13 @@ pub struct DevToolsProtocolEventReceivedEventHandler(
     Option<ICoreWebView2DevToolsProtocolEventReceivedEventArgs>,
 );
 
+#[event_callback]
+pub struct FrameContentLoadingEventHandler(
+    ICoreWebView2FrameContentLoadingEventHandler,
+    Option<ICoreWebView2Frame>,
+    Option<ICoreWebView2ContentLoadingEventArgs>,
+);
+
 #[event_callback]
 pub struct FrameCreatedEventHandler(
     ICoreWebView2FrameCreatedEventHandler,
@@ -378,6 +392,13 @@ pub struct FrameCreatedEventHandler(
     Option<ICoreWebView2FrameCreatedEventArgs>,
 );
 
+#[event_callback]
+pub struct FrameDOMContentLoadedEventHandler(
+    ICoreWebView2FrameDOMContentLoadedEventHandler,
+    Option<ICoreWebView2Frame>,
+    Option<ICoreWebView2DOMContentLoadedEventArgs>,
+);
+
 #[event_callback]
 pub struct FrameDestroyedEventHandler(
     ICoreWebView2FrameDestroyedEventHandler,
@@ -399,6 +420,27 @@ pub struct ClientCertificateRequestedEventHandler(
     Option<ICoreWebView2ClientCertificateRequestedEventArgs>,
 );
 
+#[completed_callback]
+pub struct FrameNavigationCompletedEventHandler(
+    ICoreWebView2FrameNavigationCompletedEventHandler,
+    Option<ICoreWebView2Frame>,
+    Option<ICoreWebView2NavigationCompletedEventArgs>,
+);
+
+#[event_callback]
+pub struct FrameNavigationStartingEventHandler(
+    ICoreWebView2FrameNavigationStartingEventHandler,
+    Option<ICoreWebView2Frame>,
+    Option<ICoreWebView2NavigationStartingEventArgs>,
+);
+
+#[event_callback]
+pub struct FrameWebMessageReceivedEventHandler(
+    ICoreWebView2FrameWebMessageReceivedEventHandler,
+    Option<ICoreWebView2Frame>,
+    Option<ICoreWebView2WebMessageReceivedEventArgs>,
+);
+
 #[completed_callback]
 pub struct GetCookiesCompletedHandler(
     ICoreWebView2GetCookiesCompletedHandler,
